import { LogLevel } from '@genesislcap/foundation-utils';

/**
 * Interface for Confirming Action configuration
 * @public
 */
export declare interface ConfirmingAction {
    readonly label: String;
    readonly action: Function;
}

/**
 * Interface for Dismissing Action configuration
 * @public
 */
export declare interface DismissingAction {
    readonly label: String;
    readonly action?: Function;
}

/**
 * Interface for Error Banner configuration
 * @public
 */
export declare interface ErrorBanner {
    readonly dismissingAction?: DismissingAction;
    readonly confirmingActions?: Array<ConfirmingAction>;
}

/**
 * ErrorBannerBuilder to build ErrorBanner
 * @public
 */
export declare class ErrorBannerBuilder {
    private dismissingAction;
    private confirmingActions;
    /**
     * Add dismissing action to ErrorBanner
     * @public
     * @param dismissingAction - {@link DismissingAction}
     * @returns
     */
    withDismissingAction(dismissingAction: DismissingAction): ErrorBannerBuilder;
    /**
     * Add confirming action to ErrorBanner
     * @public
     * @param confirmingAction - {@link ConfirmingAction}
     * @returns
     */
    withConfirmingAction(confirmingAction: ConfirmingAction): ErrorBannerBuilder;
    /**
     * Build ErrorBanner
     * @public
     * @returns ErrorBanner
     */
    build(): ErrorBanner;
}

/**
 * @public
 * enum for different types of error boundary events
 */
export declare enum ErrorBoundaryEvent {
    ERROR_BOUNDARY_EVENT = "error-boundary-event"
}

/**
 * ErrorBuilder to build ErrorStructure
 * @public
 */
export declare class ErrorBuilder {
    private title;
    private errorDetails;
    private logLevel;
    private alert;
    private notification;
    private banner;
    private snackbar;
    private dialog;
    /**
     * Add title to error
     * @public
     * @param title - string
     * @returns
     */
    withTitle(title: string): ErrorBuilder;
    /**
     * Add error details to error
     * @public
     * @param errorDetails - string
     * @returns
     */
    withErrorDetails(errorDetails: string): ErrorBuilder;
    /**
     * Add log level to error
     * @public
     * @returns
     */
    withLogLevel(logLevel: LogLevel): ErrorBuilder;
    /**
     * Add alert to error
     * @public
     * @param alert - boolean
     * @returns
     */
    withAlert(alert: boolean): ErrorBuilder;
    /**
     * Add notification to error
     * @public
     * @param notification - {@link ErrorNotification}
     * @returns
     */
    withNotification(notification: ErrorNotification): ErrorBuilder;
    /**
     * Add banner to error
     * @public
     * @param banner - {@link ErrorBanner}
     * @returns
     */
    withBanner(banner: ErrorBanner): ErrorBuilder;
    /**
     * Add snackbar to error
     * @public
     * @param snackbar - {@link Snackbar}
     * @returns
     */
    withSnackbar(snackbar: Snackbar): ErrorBuilder;
    /**
     * Add dialog to error
     * @public
     * @param dialog - {@link ErrorDialog}
     * @returns
     */
    withDialog(dialog: ErrorDialog): ErrorBuilder;
    /**
     * Build ErrorStructure
     * @public
     * @returns
     */
    build(): ErrorStructure;
}

/**
 * Interface for Error Dialog configuration
 * @public
 */
export declare interface ErrorDialog {
    readonly confirmingActions?: Array<ConfirmingAction>;
    readonly dismissingAction?: DismissingAction;
}

/**
 * ErrorDialogBuilder class
 * @public
 */
export declare class ErrorDialogBuilder {
    private dismissingAction;
    private confirmingActions;
    /**
     * Add dismissing action to ErrorDialog
     * @public
     * @param dismissingAction - {@link DismissingAction}
     * @returns
     */
    withDismissingAction(dismissingAction: DismissingAction): ErrorDialogBuilder;
    /**
     * Add confirming action to ErrorDialog
     * @public
     * @param confirmingAction - {@link ConfirmingAction}
     * @returns
     */
    withConfirmingAction(confirmingAction: ConfirmingAction): ErrorDialogBuilder;
    /**
     * Build ErrorDialog
     * @public
     * @returns ErrorDialog
     */
    build(): ErrorDialog;
}

/**
 * @internal
 */
export declare type ErrorDialogElement = ErrorElement & {
    show: Function;
};

/**
 * @internal
 */
export declare type ErrorElement = HTMLElement & {
    error: ErrorStructure;
};

/**
 * Interface for Error Notification configuration
 * @public
 */
export declare interface ErrorNotification {
    readonly position?: ErrorNotificationPosition;
    readonly type?: ErrorNotificationType;
    readonly autoClose?: boolean;
    readonly closeTimeout?: number;
}

/**
 * @public
 * type for error notification position
 */
export declare type ErrorNotificationPosition = 'top-left' | 'top-right' | 'bottom-left' | 'bottom-right';

/**
 * @public
 * type for error notification type
 */
export declare type ErrorNotificationType = 'warning' | 'success';

/**
 * Interface for Error Structure
 *  @public
 */
export declare interface ErrorStructure {
    readonly title: string;
    readonly errorDetails: string;
    readonly logLevel?: LogLevel;
    readonly config?: {
        /**
         * @deprecated Use logLevel from the top level instead
         */
        readonly logLevel?: LogLevel;
        readonly alert?: boolean;
        readonly notification?: ErrorNotification;
        readonly banner?: ErrorBanner;
        readonly snackbar?: Snackbar;
        readonly dialog?: ErrorDialog;
    };
}

/**
 * Get the error banner anchor to attach the banner to
 * @public
 * @param element - The element to start searching from
 * @returns
 */
export declare const getErrorBannerAnchor: (element: any) => HTMLElement | null;

/**
 * Get error banner builder instance
 * @public
 */
export declare const getErrorBannerBuilder: () => ErrorBannerBuilder;

/**
 * Returns a new ErrorBuilder instance
 * @public
 */
export declare const getErrorBuilder: () => ErrorBuilder;

/**
 * Get/Create the error container in the DOM
 * @public
 * @param id - The id of the container
 * @param tagName - The tag name to create prefix for the design system provider
 * @returns
 */
export declare const getErrorContainer: (id: string, tagName: String) => HTMLElement;

/**
 * Retrieves the error details from an ErrorStructure object
 * @public
 * @param details - The ErrorStructure object
 * @returns The title and error details concatenated as a string, or default values ('Error: Something went wrong') if not present
 */
export declare const getErrorDetails: (details: ErrorStructure) => string;

/**
 * Returns an instance of ErrorDialogBuilder
 * @public
 */
export declare const getErrorDialogBuilder: () => ErrorDialogBuilder;

/**
 * Retrieves the log level from an ErrorStructure object
 * @public
 * @param details - The ErrorStructure object
 * @returns The log level or the default value (LogLevel.Error) if not present
 */
export declare const getLoglevel: (details: ErrorStructure) => LogLevel;

/**
 * Get notification builder instance
 * @public
 */
export declare const getNotificationBuilder: () => NotificationBuilder;

/**
 * Get snackbar builder instance
 * @public
 */
export declare const getSnackbarBuilder: () => SnackbarBuilder;

/**
 * NotificationBuilder to build ErrorNotification
 * @public
 */
export declare class NotificationBuilder {
    private position;
    private autoClose;
    private closeTimeout;
    private type;
    /**
     * Add position to notification
     * @public
     * @param position - {@link ErrorNotificationPosition}
     * @returns
     */
    withPosition(position: ErrorNotificationPosition): NotificationBuilder;
    /**
     * Add auto close to notification
     * @public
     * @param autoClose - boolean
     * @returns
     */
    withAutoClose(autoClose: boolean): NotificationBuilder;
    /**
     * Add close timeout to notification
     * @public
     * @param closeTimeout - number
     * @returns
     */
    withCloseTimeout(closeTimeout: number): NotificationBuilder;
    /**
     * Add type to notification, if the type is anything other than 'warning' or 'success' do not add it
     * @public
     * @param type - {@link ErrorNotificationType}
     * @returns
     */
    withType(type: ErrorNotificationType): NotificationBuilder;
    /**
     * Build notification
     * @returns ErrorNotification
     */
    build(): ErrorNotification;
}

/**
 * Shows the error dialog
 * @public
 * @param error - The ErrorStructure object
 * @param tagName - The tag name to create prefix for the design system provider & error component
 * @returns
 * */
export declare const showBanner: (error: ErrorStructure, tagName: String, errorBoundary: HTMLElement) => void;

/**
 * Shows the error dialog
 * @internal
 * @param error - The ErrorStructure object
 * @param tagName - The tag name to create prefix for the design system provider & error component
 * @returns
 * */
export declare const showDialog: (error: ErrorStructure, tagName: String) => void;

/**
 * Shows the error in the appropriate component
 * @public
 * @param error - The ErrorStructure object
 * @param tagName - The tag name to create prefix for the design system provider *
 * @param errorBoundary - The error boundary element
 * @returns
 * */
export declare const showError: (error: ErrorStructure, tagName: String, errorBoundary?: HTMLElement) => void;

/**
 * Shows the error notification
 * @internal
 * @param error - The ErrorStructure object
 * @param tagName - The tag name to create prefix for the design system provider & error component
 * @returns
 * */
export declare const showNotification: (error: ErrorStructure, tagName: String) => void;

/**
 * Shows the snackbar
 * @internal
 * @param error - The ErrorStructure object
 * @param tagName - The tag name to create prefix for the design system provider & error component
 * @returns
 * */
export declare const showSnackbar: (error: ErrorStructure, tagName: String) => void;

/**
 * Interface for Error Snackbar configuration
 * @public
 */
export declare interface Snackbar {
    readonly type?: SnackbarType;
    readonly confirmingActions?: Array<ConfirmingAction>;
}

/**
 * SnackbarBuilder to build Snackbar
 * @public
 */
export declare class SnackbarBuilder {
    private confirmingActions;
    private type;
    /**
     * Add type to snackbar, if the type is anything other than 'error' do not add it
     * @public
     * @param type - {@link SnackbarType}
     * @returns
     */
    withType(type: SnackbarType): SnackbarBuilder;
    /**
     * Add confirming action to snackbar
     * @public
     * @param confirmingAction - {@link ConfirmingAction}
     * @returns
     */
    withConfirmingAction(confirmingAction: ConfirmingAction): SnackbarBuilder;
    /**
     * Build snackbar
     * @public
     * @returns Snackbar
     */
    build(): Snackbar;
}

/**
 * @public
 * type for snackbar type
 */
export declare type SnackbarType = 'error';

export { }
